Timer16_0

Struct Timer16_0 

pub struct Timer16_0 { /* private fields */ }
Регистры модуля таймера_0

Implementations

Source

impl Timer16_0

pub const PTR: *const RegisterBlock

Pointer to the register block

pub const fn ptr() -> *const RegisterBlock

Return the pointer to the register block

pub unsafe fn steal() -> Self

Steal an instance of this peripheral

Safety

Ensure that the new instance of the peripheral cannot be used in a way that may race with any existing instances, for example by only accessing read-only or write-only registers, or by consuming the original peripheral and using critical sections to coordinate access between multiple new instances.

Additionally, other software such as HALs may rely on only one peripheral instance existing to ensure memory safety; ensure no stolen instances are passed to such software.

Methods from Deref<Target = RegisterBlock>

pub fn isr(&self) -> &Isr

0x00 - Регистр флагов прерываний

pub fn icr(&self) -> &Icr

0x04 - Регистр сброса флагов прерываний

pub fn ier(&self) -> &Ier

0x08 - Регистр разрешения прерываний

pub fn cfgr(&self) -> &Cfgr

0x0c - Регистр конфигурации

pub fn cr(&self) -> &Cr

0x10 - Регистр управления

pub fn cmp(&self) -> &Cmp

0x14 - Регистр сравнения

pub fn arr(&self) -> &Arr

0x18 - Регистр автоматической перезагрузки

pub fn cnt(&self) -> &Cnt

0x1c - Регистр счётчика